@@ -10,6 +10,7 @@ from __future__ import annotations
 
 import asyncio
 import random
+from contextlib import suppress
 
 from typing import Any, Callable, Dict, List, Optional, TypeVar, Union
 
@@ -57,7 +58,7 @@ class TCPProtocol(asyncio.Protocol):
 
     def __init__(
         self,
-        loop: asyncio.AbstractEventLoop = None,
+        loop: asyncio.AbstractEventLoop | None = None,
         connection_callback: Optional[ConnectionCallbackType] = None,
         data_received_callback: Optional[Callable[[str], Any]] = None,
         max_connections: Optional[int] = None,
@@ -330,7 +331,8 @@ class TCPStreamServer(object):
         if self.connection_callback:
             await self._do_callback(self.connection_callback, writer.transport)
 
-        await writer.wait_closed()
+        with suppress(ConnectionResetError):
+            await writer.wait_closed()
 
 
 class TCPStreamClient:
@@ -487,7 +489,7 @@ class TopicListener(object):
 
     def __init__(
         self,
-        url: str = None,
+        url: str | None = None,
         user: str = "guest",
         password: str = "guest",
         host: str = "localhost",
